@@ -12,6 +12,7 @@ import shutil
 from typing import Optional, Any
 import json
 import tempfile
+import os
 
 class SingularityClient(ContainerClient):
     """
@@ -132,6 +133,32 @@ class SingularityClient(ContainerClient):
 
         self.config.write_compose(compose)
 
+    def build(self, *args) -> bool:
+        """Build the images.
+
+        ``singularity-compose`` won't overwrite an existing sif it already exists. Do that here.
+
+        Returns:
+            bool: Whether the command succeeded.
+        """
+
+        for service_name, service in self.config.compose["instances"].items():
+            if service_name not in self._services or "build" not in service:
+                continue
+
+            build = service["build"]
+
+            sif = Path(build.get("context", ".")) / f"{service_name}.sif"
+            if sif.exists():
+                res = input(f"The image for {service_name} has already been built. Okay to overwrite? (y|[n]) ") or "n"
+                if res == "y":
+                    os.unlink(sif)
+                elif res == "n":
+                    LOGGER.info(f"Not overwriting {service_name}.sif.")
+                else:
+                    LOGGER.warn(f"Response '{res}' is not recognized. Pass either 'y' or 'n'. Not overwriting {service_name}.sif.")
+        return super().build(*args)
+
     def up(self, *args) -> bool:
         """Bring up the containers.
 
@@ -206,7 +233,6 @@ class SingularityClient(ContainerClient):
         return self._run_cmd("singularity-compose", *args, **kwargs)
 
     def __del__(self):
-        import os
         for tmpfile in self._tmpfiles:
             if os.path.exists(tmpfile):
                 os.unlink(tmpfile)
